%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Cambridge University Press 2010
% Book: Karl Mathia (2010), Robotics for Electronics Manufacturing - 
% Principles and Applications in Cleanroom Manufacturing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Chapter 3, Example 3.1:
% Reaction forces and mechanical design of a robot arm

% Refer to the description in the book for further details.
% The following code can be executed with Matlab(R) or GNU Octave.
% (Matlab(R) is a registered trademark of The MathWorks.)

clear
clc

% Lengths of arm links and end-effectors in [m], not [mm]
l1 = 0.178;     % [m]
l2 = 0.178;     % [m]
l3 = 0.295;     % [m]

% Distances from revolute joints to the respective center of gravity (CG),
% in [m], not [mm]
l11 = 0.080;    % [m]
l22 = 0.090;    % [m]
l33 = 0.145;    % [m]

% Forces applied by the CGs in [N]
F1 = 7.5;       % [N]
F2 = 4.0;       % [N]
F3 = 7.2;       % [N]

% Vertcal distance between bearings per revolute joint in [m], not [mm]
lB1 = 0.040;    % [m]
lB2 = 0.013;    % [m]
lB3 = 0.007;    % [m]

% Moments created by the forces in [Nm]
M1 = F1*l11 + F2*(l1+l22) + F3*(l1+l2+l33);     % [Nm]
M2 = F2*l22 + F3*(l2+l33);                      % [Nm]
M3 = F3*l33;                                    % [Nm]


% Reaction forces in bearings

% Reaction forces at revolute joint RJ1 in [N]
R11z = 0;       % by definition
R12z = F1 + F2 + F3;
R11x = M1/lB1;                                  % [N]
R12x = R11x;                                    % [N]

% Reaction forces at revolute joint RJ2
R21z = 0;       % by definition
R22z = F2 + F3;
R21x = M2/lB2;                                  % [N]
R22x = R21x;                                    % [N]


% Reaction forces at revolute joint RJ3
R31z = 0;       % by definition
R32z = F3;
R31x = M3/lB3;                                  % [N]
R32x = R31x;                                    % [N]

% Display results
disp(' ')
disp('******************************************************************')
disp('***         Copyright Cambridge University Press 2010          ***')
disp('*** Karl Mathia (2010). Robotics for Electronics Manufacturing ***')
disp('***                  Chapter 3, Example 3.1                    ***')
disp('******************************************************************')
disp(' ')
disp('Reaction forces and mechanical design of a robot arm.')
disp('Please refer to the description in the book for further details.')
disp(' ')
disp('Revolute Joint 1 (RJ1):')
disp([' M1   = ', num2str(M1), ' [Nm]'])
disp([' R11z = ', num2str(R11z), ' [N]'])
disp([' R12z = ', num2str(R12z), ' [N]'])
disp([' R11x = ', num2str(R11x), ' [N]'])
disp([' R12x = ', num2str(R12x), ' [N]'])
disp(' ')
disp('Revolute Joint 2 (RJ2):')
disp([' M2   = ', num2str(M2), ' [Nm]'])
disp([' R21z = ', num2str(R21z), ' [N]'])
disp([' R22z = ', num2str(R22z), ' [N]'])
disp([' R21x = ', num2str(R21x), ' [N]'])
disp([' R22x = ', num2str(R22x), ' [N]'])
disp(' ')
disp('Revolute Joint 3 (RJ3):')
disp([' M3   = ', num2str(M3), ' [Nm]'])
disp([' R31z = ', num2str(R31z), ' [N]'])
disp([' R32z = ', num2str(R32z), ' [N]'])
disp([' R31x = ', num2str(R31x), ' [N]'])
disp([' R32x = ', num2str(R32x), ' [N]'])
disp(' ')
disp('******************************************************************')

%%%
