%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Cambridge University Press 2010
% Book: Karl Mathia (2010), Robotics for Electronics Manufacturing - 
% Principles and Applications in Cleanroom Manufacturing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Chapter 4, Example 4.3:
% Impact of a virtual leak (srew hole) on a vacuum chambers base pressure.
% Refer to the description in the book for further details.
%
% The following code can be executed with Matlab(R) or GNU Octave.
% (Matlab(R) is a registered trademark of The MathWorks.)

clear
clc


% Reference: Mende-Simon p. 115: thermodynamics
%     p1*V1/T1 = p2*V2/T2, p=pressure, V=volume, T=temperature
% With approximation T1=T2:
%     p1*V1 = p2*V2
%
% State 1: air pocket under atmospheric pressure before pumpdown
d = 0.005;                  % diameter [m]
h = 0.002;                  % height [m]
V1 = pi * (d/2)^2 * h;      % volume 1 [m^3]
V1_liter = V1*1000;         % volume 1 in [liter]
p1 = 101325;                % pressure 1 [Pa] = 760 [Torr] = 1 [atm]
p1_Torr = p1/133.3224;      % pressure 1 [Torr]

% State 2: air pocket becomes a virtual leak after pumpdown, air leaks into 
% the chamber
V2 = 0.1;                   % Chamber volume [m^3]
V2_liter = V2*1000;         % Chamber volume [liter]

% We want to know: pressure in State 2 after the virtual leak escapes into 
% the chamber
p2 = V1/V2*p1;              % pressure 2 [Pa]
p2_Torr = p2/133.3224;      % pressure 2 [Torr]

% Display results
disp(' ')
disp('******************************************************************')
disp('***         Copyright Cambridge University Press 2010          ***')
disp('*** Karl Mathia (2010). Robotics for Electronics Manufacturing ***')
disp('***                  Chapter 4, Example 4.3                    ***')
disp('******************************************************************')
disp(' ')
disp('Impact of a virtual leak on a vacuum chambers base pressure.')
disp('Please refer to the description in the book for further details.')
disp(' ')
disp('Thermodynamic equation for ideal gasses: p1*V1/T1 = p2*V2/T2')
disp('Given:    p1, V1, V2, T1 = T2')
disp('Desired:  p2')
disp(' ')
disp('Virtual leak:')
disp(['d  = ',num2str(d),' [m]'])
disp(['h  = ',num2str(h),' [m]'])
disp(' ')
disp('State 1:')
disp(['V1 = ',num2str(V1),' [m^3] = ',num2str(V1_liter),' [liter]'])
disp(['p1 = ',num2str(p1),' [Pa] = ',num2str(p1_Torr),' [Torr]'])
disp(' ')
disp('State 2:')
disp(['V2 = ',num2str(V2),' [m^3] = ',num2str(V2_liter),' [liter]'])
disp(['p2 = ',num2str(p2),' [Pa] = ',num2str(p2_Torr),' [Torr]'])
disp(' ')
disp('******************************************************************')

%%%