%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Cambridge University Press 2010
% Book: Karl Mathia (2010), Robotics for Electronics Manufacturing - 
% Principles and Applications in Cleanroom Manufacturing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Chapter 4, Example 4.4:
% Converting the Total Mass Loss of aluminum to its Outgassing Rate OR.
% Refer to the description in the book for further details.
%
% The following code can be executed with Matlab(R) or GNU Octave.
% (Matlab(R) is a registered trademark of The MathWorks.)

clear
clc
    
% Aluminum properties
M_Al = 26.98;           % molar weight [gram/mol]

% Standard parameters from the ideal gas law
p_std = 760;            % standard pressure [torr]
V_std = 22.4;           % standard volume [liter/mol]

% Nominal test parameters per ASTM standard E-595
m_nom = 0.25;           % nominal mass [gram]
A_nom = 0.3167;         % nominal outgassing area [cm2]
t_nom = 24*60*60;       % delta t, nominal test period [sec]

% Intermediate, constant factor K
M_mat = M_Al;
K = (p_std * V_std) / (M_mat * t_nom);

% Example 1
% LAMINATE SHIM ALUMINUM (NASA sample ID GSC10284):
TML1 = 0.0005;          % (or 0.05%)
OR1 = (m_nom * TML1)/A_nom * K;

% Example 2
% PAA-CORE ALUMINUM HONEYCOMB (NASA sample ID GSC18471):
TML2 = 0.0006;       % (or 0.06%)
OR2 = (m_nom * TML2)/A_nom * K;


% Display results
disp(' ')
disp('******************************************************************')
disp('***         Copyright Cambridge University Press 2010          ***')
disp('*** Karl Mathia (2010). Robotics for Electronics Manufacturing ***')
disp('***                  Chapter 4, Example 4.4                    ***')
disp('******************************************************************')
disp(' ')
disp('Converting the Total Mass Loss (TML) of aluminum to its Outgassing ')
disp('Rate OR.')
disp('Please refer to the description in the book for further details.')
disp(' ')
disp(['  Intermediate, constant factor K:'])
disp(['     K = ',num2str(K),' [torr liter/(g sec)]'])
disp(' ')
disp(['  LAMINATE SHIM ALUMINUM (sample ID GSC10284) TML = 0.0005'])
disp(['     OR1 = ',num2str(OR1),' [(torr liter)/(cm2 sec)]'])
disp(' ')
disp(['  PAA-CORE ALUMINUM HONEYCOMB (sample ID GSC18471) TML = 0.0006'])
disp(['     OR2 = ',num2str(OR2),' [(torr liter)/(cm2 sec)]'])
disp(' ')
disp('******************************************************************')

%%%
