function [ee,link1,link2,link3] = fkinematics_r3p1(l1,l2,l3,q1,q2,q3)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Cambridge University Press 2010
% Book: Karl Mathia (2010), Robotics for Electronics Manufacturing - 
% Principles and Applications in Cleanroom Manufacturing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Chapter 5, Example 5.1:
% Kinematic structure of a 3-link planar robot.
% Refer to the description in the book for further details.
%
% The following code can be executed with Matlab(R) or GNU Octave.
% (Matlab(R) is a registered trademark of The MathWorks.)

% FKINEMATICS_R3P1  Forward kinematics of planar 3-link manipulator 
% (3 rotary joints, 1 prismatic joint). Here: the vertical robot axis is
% not shown. The origin assumed zero.
% Returns: end-effector tool point, link1 vector, link2 vector. 


link1 = [l1 * cos(q1);
         l1 * sin(q1)];
link2 = [l2 * cos(q1 + q2);
         l2 * sin(q1 + q2)];
link3 = [l3 * cos(q1 + q2 + q3);
         l3 * sin(q1 + q2 + q3)];

ee = link1 + link2 + link3;

%%%